==> mokkery-runtime-androidnativearm64-1.0-javadoc.jar: mokkery-runtime/dev.mokkery.answering/-function-scope/index.md <==
//[mokkery-runtime](../../../index.md)/[dev.mokkery.answering](../index.md)/[FunctionScope](index.md)

# FunctionScope

[common]\
class [FunctionScope](index.md)(val returnType: [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt;, val args: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt;)

Provides function call arguments. If function has any extension receiver, it is provided at the beginning of the [args](args.md) list.

## Constructors

| | |
|---|---|
| [FunctionScope](-function-scope.md) | [common]<br>constructor(returnType: [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt;, args: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt;) |

## Properties

| Name | Summary |
|---|---|
| [args](args.md) | [common]<br>val [args](args.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt; |
| [returnType](return-type.md) | [common]<br>val [returnType](return-type.md): [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt; |

## Functions

| Name | Summary |
|---|---|
| [component1](component1.md) | [common]<br>operator fun &lt;[T](component1.md)&gt; [component1](component1.md)(): [T](component1.md) |
| [component2](component2.md) | [common]<br>operator fun &lt;[T](component2.md)&gt; [component2](component2.md)(): [T](component2.md) |
| [component3](component3.md) | [common]<br>operator fun &lt;[T](component3.md)&gt; [component3](component3.md)(): [T](component3.md) |
| [component4](component4.md) | [common]<br>operator fun &lt;[T](component4.md)&gt; [component4](component4.md)(): [T](component4.md) |
| [component5](component5.md) | [common]<br>operator fun &lt;[T](component5.md)&gt; [component5](component5.md)(): [T](component5.md) |
| [component6](component6.md) | [common]<br>operator fun &lt;[T](component6.md)&gt; [component6](component6.md)(): [T](component6.md) |
| [component7](component7.md) | [common]<br>operator fun &lt;[T](component7.md)&gt; [component7](component7.md)(): [T](component7.md) |
| [equals](equals.md) | [common]<br>open operator override fun [equals](equals.md)(other: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [hashCode](hash-code.md) | [common]<br>open override fun [hashCode](hash-code.md)(): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [toString](to-string.md) | [common]<br>open override fun [toString](to-string.md)(): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |

==> mokkery-runtime-androidnativearm64-1.9.0-1.1.0-javadoc.jar: mokkery-runtime/dev.mokkery.answering/-function-scope/index.md <==
//[mokkery-runtime](../../../index.md)/[dev.mokkery.answering](../index.md)/[FunctionScope](index.md)

# FunctionScope

[common]\
class [FunctionScope](index.md)(val returnType: [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt;, val args: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt;, val self: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?)

Provides function call arguments. If function has any extension receiver, it is provided at the beginning of the [args](args.md) list.

## Constructors

| | |
|---|---|
| [FunctionScope](-function-scope.md) | [common]<br>constructor(returnType: [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt;, args: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt;, self: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?) |

## Properties

| Name | Summary |
|---|---|
| [args](args.md) | [common]<br>val [args](args.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?&gt; |
| [returnType](return-type.md) | [common]<br>val [returnType](return-type.md): [KClass](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.reflect/-k-class/index.html)&lt;*&gt; |
| [self](self.md) | [common]<br>val [self](self.md): [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)? |

## Functions

| Name | Summary |
|---|---|
| [component1](component1.md) | [common]<br>operator fun &lt;[T](component1.md)&gt; [component1](component1.md)(): [T](component1.md) |
| [component2](component2.md) | [common]<br>operator fun &lt;[T](component2.md)&gt; [component2](component2.md)(): [T](component2.md) |
| [component3](component3.md) | [common]<br>operator fun &lt;[T](component3.md)&gt; [component3](component3.md)(): [T](component3.md) |
| [component4](component4.md) | [common]<br>operator fun &lt;[T](component4.md)&gt; [component4](component4.md)(): [T](component4.md) |
| [component5](component5.md) | [common]<br>operator fun &lt;[T](component5.md)&gt; [component5](component5.md)(): [T](component5.md) |
| [component6](component6.md) | [common]<br>operator fun &lt;[T](component6.md)&gt; [component6](component6.md)(): [T](component6.md) |
| [component7](component7.md) | [common]<br>operator fun &lt;[T](component7.md)&gt; [component7](component7.md)(): [T](component7.md) |
| [equals](equals.md) | [common]<br>open operator override fun [equals](equals.md)(other: [Any](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)?): [Boolean](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html) |
| [hashCode](hash-code.md) | [common]<br>open override fun [hashCode](hash-code.md)(): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html) |
| [self](self.md) | [common]<br>inline fun &lt;[T](self.md)&gt; [self](self.md)(): [T](self.md) |
| [toString](to-string.md) | [common]<br>open override fun [toString](to-string.md)(): [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
